﻿using System;
using System.Drawing;
using System.Collections.Generic;
using SketchPad.Spatial;


namespace SketchPad.EF
{
    public partial class Line : ILine
    {
        int IIdentity.ID
        {
            get
            {
                return base.ID;
            }
        }

        string IIdentity.Description
        {
            get
            {
                return base.Description;
            }
        }

        public void Draw(Graphics g, Pen pen)
        {
            g.DrawLine(pen, new Point(this.Ax, this.Ay), new Point(this.Bx, this.By));
        }

        public void Select(Graphics g, Pen pen)
        {
            g.DrawRectangles(pen, new Rectangle[] { 
                                      Util.CreateSelectionHandle(Ax, Ay), 
                                      Util.CreateSelectionHandle(Bx, By) 
                                });
        }

        public Rectangle GetBoundingBox()
        {
            int upperLeftX = Ax < Bx ? Ax : Bx;
            int upperLeftY = Ay < By ? Ay : By;

            int width = Math.Abs(Ax - Bx);
            int height = Math.Abs(Ay - By);

            Rectangle rectangle = new Rectangle(upperLeftX, upperLeftY,
                                                width, height);
            return rectangle;
        }
    }

    public partial class Circle : ICircle
    {
        int IIdentity.ID
        {
            get
            {
                return base.ID;
            }
        }

        string IIdentity.Description
        {
            get
            {
                return base.Description;
            }
        }

        public void Draw(Graphics g, Pen pen)
        {
            Util.DrawCircleHelper(g, pen,
                                  new Point(this.Ax, this.Ay),
                                  new Point(this.Bx, this.By));
        }

        public void Select(Graphics g, Pen pen)
        {
            g.DrawRectangle(pen, Util.CreateSelectionHandle(this.Ax, this.Ay));
        }

        public Rectangle GetBoundingBox()
        {
            return Util.ComputeBoundingRectangle(
                                new Point(this.Ax, this.Ay),
                                new Point(this.Bx, this.By));
        }
    }
}