﻿using System;
using System.Drawing;
using System.Collections.Generic;
using System.Data.Linq;
using System.Data.Linq.Mapping;
using SketchPad.Spatial;


namespace SketchPad.LinqToSql
{
    [InheritanceMapping(Code="S", Type=typeof(Shape), IsDefault=true)]
    [InheritanceMapping(Code="L", Type=typeof(Line))]
    [InheritanceMapping(Code="C", Type=typeof(Circle))]
    [Table(Name="dbo.[Shape]")]
    public class Shape
    {
        public Shape()
        {
        }

        public Shape(string description, char tag)
        {
            this.Description = description;
            this.Tag = tag;
        }

        [Column(IsPrimaryKey=true, IsDbGenerated=true)]
        public int ID;

        [Column]
        public string Description;

        [Column(IsDiscriminator=true)]
        public char Tag;
    }

    public partial class Line : Shape, ILine
    {
        public Line()
        {
        }

        public Line(Point a, Point b, string description) :
            base(description, 'L')
        {
            this.Ax = a.X; this.Ay = a.Y; this.Bx = b.X; this.By = b.Y;
        }

        [Column]
        public int Ax;

        [Column]
        public int Ay;

        [Column]
        public int Bx;

        [Column]
        public int By;

        int IIdentity.ID
        {
            get
            {
                return base.ID;
            }
        }

        string IIdentity.Description
        {
            get
            {
                return base.Description;
            }
        }

        public void Draw(Graphics g, Pen pen)
        {
            g.DrawLine(pen, new Point(this.Ax, this.Ay), new Point(this.Bx, this.By));
        }

        public void Select(Graphics g, Pen pen)
        {
            g.DrawRectangles(pen, new Rectangle[] { 
                                      Util.CreateSelectionHandle(Ax, Ay), 
                                      Util.CreateSelectionHandle(Bx, By) 
                                });
        }

        public Rectangle GetBoundingBox()
        {
            int upperLeftX = Ax < Bx ? Ax : Bx;
            int upperLeftY = Ay < By ? Ay : By;

            int width = Math.Abs(Ax - Bx);
            int height = Math.Abs(Ay - By);

            Rectangle rectangle = new Rectangle(upperLeftX, upperLeftY,
                                                width, height);
            return rectangle;
        }
    }

    public partial class Circle : Shape, ICircle
    {
        public Circle()
        {
        }

        public Circle(Point center, Point circumference, string description) :
            base(description, 'C')
        {
            this.CenterX = center.X;
            this.CenterY = center.Y;
            this.CircumferenceX = circumference.X;
            this.CircumferenceY = circumference.Y;
        }

        [Column(Name="Ax")]
        public int CenterX;

        [Column(Name="Ay")]
        public int CenterY;

        [Column(Name="Bx")]
        public int CircumferenceX;

        [Column(Name="By")]
        public int CircumferenceY;

        int IIdentity.ID
        {
            get
            {
                return base.ID;
            }
        }

        string IIdentity.Description
        {
            get
            {
                return base.Description;
            }
        }

        public void Draw(Graphics g, Pen pen)
        {
            Util.DrawCircleHelper(g, pen,
                                  new Point(CenterX, CenterY),
                                  new Point(CircumferenceX, CircumferenceY));
        }

        public void Select(Graphics g, Pen pen)
        {
            g.DrawRectangle(pen, Util.CreateSelectionHandle(CenterX, CenterY));
        }

        public Rectangle GetBoundingBox()
        {
            return Util.ComputeBoundingRectangle(
                                new Point(CenterX, CenterY),
                                new Point(CircumferenceX, CircumferenceY));
        }
    }
}