﻿using System;
using System.Drawing;
using System.Windows.Forms;

namespace SketchPad
{
    public partial class Splash : Form
    {
        private bool _usingEF;
        private static int s_padding = 3;
        private static int s_penWidth = 3;

        public Splash(bool usingEF)
        {
            this._usingEF = usingEF;
            InitializeComponent();
        }

        private void Splash_Paint(object sender, PaintEventArgs e)
        {
            Cursor.Current = Cursors.WaitCursor;    // needs to be done here (as opposed to in Form Load)

            Graphics g = e.Graphics;
            Form form = sender as Form;

            using (Pen clientBorderPen = new Pen(Color.Black, s_penWidth))
            using (Pen textBorderPen = new Pen(Color.Red, s_penWidth))
            using (Font titleFont = new Font(FontFamily.GenericSansSerif, 36.0F, FontStyle.Bold))
            using (Font subtitleFont = new Font(FontFamily.GenericSansSerif, 12.0F, FontStyle.Bold))
            using (Brush titleBrush = new SolidBrush(Color.DarkSlateBlue))
            using (Brush subtitleBrush = new SolidBrush(Color.DarkRed))
            {
                g.DrawRectangle(clientBorderPen, form.ClientRectangle);

                string title = "SketchPad v1.0";
                string subTitle = this._usingEF ? "Using the Entity Framework" : "Using LINQ to SQL";
                SizeF titleSize = g.MeasureString(title, titleFont);

                int x = Convert.ToInt32((form.ClientRectangle.Width - titleSize.Width) / 2);
                int y = Convert.ToInt32((form.ClientRectangle.Height - titleSize.Height) / 2);

                Rectangle border = new Rectangle(x, y, Convert.ToInt32(titleSize.Width), Convert.ToInt32(titleSize.Height));
                SizeF subtitleSize = g.MeasureString(subTitle, subtitleFont);

                border.Inflate(s_padding, s_padding);
                border.Height += Convert.ToInt32(subtitleSize.Height);

                g.DrawRectangle(textBorderPen, border);
                g.DrawString(title, titleFont, titleBrush, x, y);
                g.DrawString(subTitle, subtitleFont, subtitleBrush, x + s_padding, y + Convert.ToInt32(titleSize.Height));
            }
        }
    }
}
