﻿using System;
using System.Drawing;
using System.Collections.Generic;


namespace SketchPad.Spatial
{
    public static class Util
    {
        private static int SelectHandleSize = 7;

        /// <summary>
        /// Compute the Euclidean distance between two points
        /// </summary>
        /// <param name="A">First point</param>
        /// <param name="B">Second point</param>
        /// <returns>The distance between the two points expressed as an integer</returns>
        public static int ComputeDistance(Point A, Point B)
        {
            int distance = Convert.ToInt32(Math.Sqrt(
                                        (A.X - B.X) * (A.X - B.X) +
                                        (A.Y - B.Y) * (A.Y - B.Y)
                                                    ));
            System.Diagnostics.Debug.WriteLine(string.Format("Distance from {0} to {1} is {2}", A, B, distance));
            return distance;
        }

        /// <summary>
        /// Compute the rectangular region circumscribing a circle
        /// </summary>
        /// <param name="center">The center of the circle</param>
        /// <param name="circumference">A point on the circumference of the circle</param>
        /// <returns>A rectangle circumscribing the circle</returns>
        public static Rectangle ComputeBoundingRectangle(Point center, Point circumference)
        {
            int radius = Util.ComputeDistance(center, circumference);

            return new Rectangle(center.X - radius, center.Y - radius, radius * 2, radius * 2);
        }

        /// <summary>
        /// Draw a circle on the canvas
        /// </summary>
        /// <param name="g">The Graphics object to use</param>
        /// <param name="pen">The Pen object to use</param>
        /// <param name="center">The center of the circle</param>
        /// <param name="circumference">A point on the circumference of the circle</param>
        public static void DrawCircleHelper(Graphics g, Pen pen, Point center, Point circumference)
        {
            g.DrawEllipse(pen, Util.ComputeBoundingRectangle(center, circumference));
        }

        /// <summary>
        /// Utility method used to draw the selection "handles" on various shapes
        /// </summary>
        /// <param name="x"></param>
        /// <param name="y"></param>
        /// <returns>A rectangle object that can be drawn to indicate that a shape
        /// has been selected in the editor</returns>
        public static Rectangle CreateSelectionHandle(int x, int y)
        {
            return new Rectangle(x - (Util.SelectHandleSize/2), y - (Util.SelectHandleSize/2), 
                                    Util.SelectHandleSize, Util.SelectHandleSize);
        }
        /*
        /// <summary>
        /// Utility method to add some shapes to the database [one-time use only]
        /// </summary>
        public static void SeedDatabase()
        {
            using (SpatialDBEntities database = new SpatialDBEntities())
            {
                SpatialDBModel.Shape s1 = SpatialDBModel.Shape.CreateShape(0);
                s1.Circle = SpatialDBModel.Circle.CreateCircle(400, 200, 450, 250, 0);
                s1.Description = "Audi Ring 3";
                database.AddToShape(s1);

                SpatialDBModel.Shape s2 = SpatialDBModel.Shape.CreateShape(0);
                s2.Circle = SpatialDBModel.Circle.CreateCircle(500, 200, 550, 250, 0);
                s2.Description = "Audi Ring 4";
                database.AddToShape(s2);

                database.SaveChanges();
            }
        }
         */
    }
}
